@@ -1,5 +1,5 @@
 
-from milkycow import *
+from chipperchicken import *
 from re import search, ASCII
 from getpass import getpass as ainput
 from os import remove, stat
@@ -41,8 +41,8 @@ class Fundb:
         """
         if(type(data) != dict):
             raise Exception(RDATA["TYE2"])
-        with open(self.db_name+self.exten, "w") as a:
-            enc_data = encrypt(str(data), self.passwd, self.rotate)
+        with open(self.db_name+self.exten, "wb") as a:
+            enc_data = encrypt(str(data).encode(), self.passwd, self.rotate)
             a.write(enc_data)
             a.close()
             if(verbose):
@@ -56,8 +56,8 @@ class Fundb:
         >>> mdb.read()
         """
         try:
-            with open(self.db_name+self.exten, "r") as a:
-                data = decrypt(a.read(), self.passwd, self.rotate)
+            with open(self.db_name+self.exten, "rb") as a:
+                data = decrypt(a.read(), self.passwd, self.rotate).decode()
                 a.close()
                 return eval(data)
         except UnicodeDecodeError:
@@ -75,8 +75,8 @@ class Fundb:
 >>> # write what ever you want. use free_read() to get tha data back
         >>> mdb.free_write("data")
         """
-        with open(self.db_name+self.exten, "w") as a:
-            enc_data = encrypt(str(data), self.passwd, self.rotate)
+        with open(self.db_name+self.exten, "wb") as a:
+            enc_data = encrypt(str(data).encode(), self.passwd, self.rotate)
             a.write(enc_data)
             a.close()
             if(verbose):
@@ -90,10 +90,10 @@ class Fundb:
         >>> mdb.free_read()
         """
         try:
-            with open(self.db_name+self.exten, "r") as a:
-                data = decrypt(a.read(), self.passwd, self.rotate)
+            with open(self.db_name+self.exten, "rb") as a:
+                data = decrypt(a.read(), self.passwd, self.rotate).decode()
                 a.close()
-                return bdec(data)
+                return data
         except UnicodeDecodeError:
             raise Exception(RDATA["UDE"])
         except FileNotFoundError:
